# Jax-Implementation of Variational Hidden Markov Model

[![Python application](https://github.com/morim3/VariationalHMM/actions/workflows/python-app.yml/badge.svg)](https://github.com/morim3/VariationalHMM/actions/workflows/python-app.yml)

## Feature
✨ Fast Parallel Variational inference of Hidden Markov Model.

💫 Implements "Temporal Parallelization of Inference in Hidden Markov Models" to achieve fast parallel inference.

## Reference 
https://arxiv.org/pdf/2102.05743.pdf
